@@ -1,13 +1,16 @@
 import json
+from json import JSONDecodeError
 
 from isc_common.string import StrToBytes, BytesToStr
 
 
 def BytesToJson(mybytes):
-    mystring = BytesToStr(mybytes)
-    _json = json.loads(mystring)
-    return _json
-
+    try:
+        mystring = BytesToStr(mybytes)
+        _json = json.loads(mystring)
+        return _json
+    except JSONDecodeError:
+        return dict()
 
 def JsonToBytes(meyjson):
     mystring = json.dumps(meyjson)
